==> style-o-matic-1.1.5.tgz: package/es/components/ToolBar/ToolBarItem.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, getValidProps, getElementType, setCorePropDefaults, ROLE } from "../../lib";

var ToolBarItem = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarItem, _CoreComponent);

  function ToolBarItem() {
    _classCallCheck(this, ToolBarItem);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBarItem.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        uiclass = _getValidProps.uiclass,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var ElementType = getElementType(ToolBarItem, this.props);

    var classes = {
      active: to && path.indexOf(to) !== -1
    };

    if (icon || text) {
      return React.createElement(
        ElementType,
        _extends({}, props, {
          className: classNames(className, classes),
          href: to,
          label: text
        }),
        React.createElement("i", { className: uiclass + "-icon " + icon }),
        React.createElement(
          "span",
          { className: uiclass + "-info" },
          text
        ),
        children
      );
    }

    return React.createElement(
      ElementType,
      _extends({}, props, { className: classNames(className, classes) }),
      children
    );
  };

  return ToolBarItem;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.ITEM,
  text: ""
}), _temp);


export default ToolBarItem;

==> style-o-matic-1.1.37.tgz: package/es/components/ToolBar/ToolBarItem.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, getValidProps, getElementType, getCorePropDefaults, ROLE } from "../../lib";

var ToolBarItem = (_temp = _class = function (_CoreComponent) {
  _inherits(ToolBarItem, _CoreComponent);

  function ToolBarItem() {
    _classCallCheck(this, ToolBarItem);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  ToolBarItem.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        uiclass = _getValidProps.uiclass,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var ElementType = getElementType(ToolBarItem, this.props);

    var classes = {
      active: to && path.indexOf(to) !== -1
    };

    if (icon || text) {
      return React.createElement(
        ElementType,
        _extends({}, props, {
          className: classNames(className, classes),
          href: to,
          label: text
        }),
        React.createElement("i", { className: uiclass + "-icon " + icon }),
        React.createElement(
          "span",
          { className: uiclass + "-info" },
          text
        ),
        children
      );
    }

    return React.createElement(
      ElementType,
      _extends({}, props, { className: classNames(className, classes) }),
      children
    );
  };

  return ToolBarItem;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.ITEM,
  text: ""
}), _temp);


export default ToolBarItem;
